@@ -436,6 +436,11 @@ def get_parser():
     # Fieldmap options
     g_fmap = parser.add_argument_group(
         'Specific options for handling fieldmaps')
+    g_fmap.add_argument(
+        '--denoised_image_sdc', '--denoised_image_sdc',
+        action='store_true',
+        default=False,
+        help='use denoised b=0 images if available instead of raw (from BIDS) images in SDC')
     g_fmap.add_argument(
         '--prefer_dedicated_fmaps', '--prefer-dedicated-fmaps',
         action='store_true',
@@ -846,7 +851,7 @@ def build_qsiprep_workflow(opts, retval):
 
     # Load base plugin_settings from file if --use-plugin
     if opts.use_plugin is not None:
-        from yaml import load as loadyml
+        from yaml import safe_load as loadyml
         with open(opts.use_plugin) as f:
             plugin_settings = loadyml(f)
         plugin_settings.setdefault('plugin_args', {})
@@ -972,6 +977,7 @@ def build_qsiprep_workflow(opts, retval):
         hmc_transform=opts.hmc_transform,
         hmc_model=opts.hmc_model,
         eddy_config=opts.eddy_config,
+        raw_image_sdc=not opts.denoised_image_sdc,
         shoreline_iters=opts.shoreline_iters,
         impute_slice_threshold=opts.impute_slice_threshold,
         b0_to_t1w_transform=opts.b0_to_t1w_transform,
@@ -1080,7 +1086,7 @@ def build_recon_workflow(opts, retval):
 
     # Load base plugin_settings from file if --use-plugin
     if opts.use_plugin is not None:
-        from yaml import load as loadyml
+        from yaml import safe_load as loadyml
         with open(opts.use_plugin) as f:
             plugin_settings = loadyml(f)
         plugin_settings.setdefault('plugin_args', {})
