@@ -43,6 +43,7 @@ def init_dwi_preproc_wf(dwi_only,
                         shoreline_iters,
                         impute_slice_threshold,
                         eddy_config,
+                        raw_image_sdc,
                         reportlets_dir,
                         output_spaces,
                         output_dir,
@@ -84,6 +85,7 @@ def init_dwi_preproc_wf(dwi_only,
                                   shoreline_iters=2,
                                   impute_slice_threshold=0,
                                   eddy_config=None,
+                                  raw_image_sdc=False,
                                   reportlets_dir='.',
                                   output_spaces=['T1w', 'template'],
                                   dwi_denoise_window=5,
@@ -369,6 +371,7 @@ Diffusion data preprocessing
             source_file=source_file,
             impute_slice_threshold=impute_slice_threshold,
             eddy_config=eddy_config,
+            raw_image_sdc=raw_image_sdc,
             mem_gb=mem_gb,
             omp_nthreads=omp_nthreads,
             fmap_bspline=fmap_bspline,
