@@ -12,6 +12,7 @@ from .dipy import (init_dipy_brainsuite_shore_recon_wf, init_dipy_mapmri_recon_w
 from .mrtrix import (init_mrtrix_csd_recon_wf, init_global_tractography_wf,
                      init_mrtrix_tractography_wf, init_mrtrix_connectivity_wf)
 from .amico import init_amico_noddi_fit_wf
+from .pyafq import init_pyafq_wf
 from .converters import init_mif_to_fibgz_wf, init_qsiprep_to_fsl_wf
 from .dynamics import init_controllability_wf
 from .utils import init_conform_dwi_wf, init_discard_repeated_samples_wf
@@ -143,12 +144,12 @@ def init_dwi_recon_workflow(dwi_file, workflow_spec, output_dir, prefer_dwi_mask
     # Fill-in datasinks and reportlet datasinks seen so far
     for node in workflow.list_node_names():
         node_suffix = node.split('.')[-1]
-        if node_suffix.startswith('ds_'):
-            workflow.connect(inputnode, 'dwi_file', workflow.get_node(node), 'source_file')
-            if "report" in node_suffix:
-                workflow.get_node(node).inputs.base_directory = reportlets_dir
-            else:
-                workflow.get_node(node).inputs.base_directory = output_dir
+        if node_suffix.startswith('ds'):
+            base_dir = reportlets_dir if "report" in node_suffix else output_dir
+            # LOGGER.info("setting %s base dir to %s", node_suffix, base_dir )
+            workflow.get_node(node).inputs.base_directory = base_dir
+            if node_suffix.startswith('ds_'):
+                workflow.connect(inputnode, 'dwi_file', workflow.get_node(node), 'source_file')
 
     return workflow
 
@@ -209,6 +210,11 @@ def workflow_from_spec(omp_nthreads, available_anatomical_data, node_spec,
     elif software == "AMICO":
         if node_spec["action"] == "fit_noddi":
             return init_amico_noddi_fit_wf(**kwargs)
+
+    elif software == "pyAFQ":
+        if node_spec["action"] == "pyAFQ_full":
+            return init_pyafq_wf(**kwargs)
+
     # qsiprep operations
     else:
         if node_spec['action'] == "controllability":
